@@ -15,11 +15,22 @@ except ModuleNotFoundError as e:
 
 print("SHOULD_USE_SPAN", SHOULD_USE_SPAN)
 
+import time
+
+
+@contextmanager
+def print_span(label: str):
+    start = time.time()
+    yield
+    time_took = time.time() - start
+    print(f"{label} took {time_took*1_000:.5f} ms.")
+
 
 @contextmanager
 def safe_span(label, use=True):
     if not SHOULD_USE_SPAN or not use:
-        yield
+        with print_span(label):
+            yield
     else:
         with span(label):
             yield
